package App::gitfancy;
{
  $App::gitfancy::VERSION = '0.003';
}
use strict;
use warnings;
# ABSTRACT: shows `git log` with a more readable graph

1;



=pod

=encoding utf-8

=head1 NAME

App::gitfancy - shows `git log` with a more readable graph

=head1 VERSION

version 0.003

=head1 SYNOPSIS

	git-fancy [options] [-- arguments for git-log]

=head1 DESCRIPTION

see L<git-fancy>.

=head1 SEE ALSO

L<git|http://www.git-scm.com>

=head1 AUTHOR

Geunyoung Park <gypark@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2012 by Geunyoung Park.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut


__END__

